# BPMScan

Ever imagined that from a video footage can you measure heart rate of a person? Well, Yeah! It is possible and the technology behind that is Remote-photoplethysmography (rPPG) and Face tracking. Try Out :)

# Installation

```bash
$ pip3 install bpmscan
```

# Usage

```bash
$ bpmscan #Defaults to webcam(camera_id=0)
$ bpmscan [camera_id, ipcamera_address, video_file_path] #Optional to use
```

# Disclaimer

This project is made for a coursework and represents only educational usage. This should not be used as a means of medical instrument, software or as a reference to measure any health vitals as this is under development and may give errenous result. The author is not responsible for any incidents occuring after violating this Disclaimer. 
